==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CalloutContentUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalloutContentUpdatingEventArgsDescription } from "./CalloutContentUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutContentUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalloutContentUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutContentUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutContentUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutContentUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutContentUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutContentUpdatingEventArgsDescriptionMetadata.c(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(CalloutContentUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("ContentRef", "(w:Content,j:content,wf:Content)DataRef");
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutContentUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("CalloutContentUpdatingEventArgs", function () { return new CalloutContentUpdatingEventArgsDescription(); });
        a.z("CalloutContentUpdatingEventArgs", CalloutContentUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutContentUpdatingEventArgsDescriptionMetadata, 'CalloutContentUpdatingEventArgsDescriptionMetadata');
    CalloutContentUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutContentUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutContentUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CalloutContentUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalloutContentUpdatingEventArgsDescription } from "./CalloutContentUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutContentUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalloutContentUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutContentUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutContentUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutContentUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutContentUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutContentUpdatingEventArgsDescriptionMetadata.c(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(CalloutContentUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalloutContentUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("ContentRef", "(w:Content,j:content,wf:Content)DataRef");
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutContentUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("CalloutContentUpdatingEventArgs", function () { return new CalloutContentUpdatingEventArgsDescription(); });
        a.ab("CalloutContentUpdatingEventArgs", CalloutContentUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutContentUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutContentUpdatingEventArgsDescriptionMetadata, 'CalloutContentUpdatingEventArgsDescriptionMetadata');
    CalloutContentUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutContentUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutContentUpdatingEventArgsDescriptionMetadata };
